@@ -1,8 +1,6 @@
-# -*- coding: utf-8 -*-
-
 """A getter for Pathway Commons."""
 
-from bioversions.utils import Getter, VersionType, get_soup
+from bioversions.utils import Getter, VersionType, find, get_soup
 
 __all__ = [
     "PathwayCommonsGetter",
@@ -20,10 +18,10 @@ class PathwayCommonsGetter(Getter):
     def get(self) -> str:
         """Get the latest Pathway Commons version number."""
         soup = get_soup(URL)
-        boost = soup.find(**{"class": "boost"})
-        boost = boost.text[len("Version ") :]
-        boost = boost.split(":")[0]
-        return boost
+        boost = find(soup, {"class": "boost"})
+        boost_text = boost.text[len("Version ") :]
+        boost_text = boost_text.split(":")[0]
+        return boost_text
 
 
 if __name__ == "__main__":
